# proteyn

Computational Protein Design Library for Python Developers

## Docs 

## Structure Prediction

You can pick from a range of structure prediction tools such as Alphafold or ESM fold. For now, you have to run them on our infrastructure but we hope to "bring-your-own-compute" soon!
